; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted


;-| Super Motions |--------------------------------------------------------
[Command]
name = "KIKANSYA"
command = /F,x
time = 1

[Command]
name = "URADORA"
command = /F,y
time = 1

[Command]
name = "YUUJYOUPOWER"
command = x
time = 1

[Command]
name = "DORAYAKIN"
command = x
time = 1

[Command]
name = "NANKANAIKA"
command = y
time = 1

[Command]
name = "TOMODACHI"
command = z
time = 1

;-| Hissatu Motions |--------------------------------------------------------
[Command]
name = "doraneko"
command =  D, F, a
time = 20

[Command]
name = "door"
command =  D, F, b
time = 20

[Command]
name = "neji"
command = D, F, c
time = 20

[Command]
name = "kaminari"
command =  D, F, x
time = 20

[Command]
name = "korobasiya"
command = D, F, y
time = 20

[Command]
name = "yari"
command = D, F, z
time = 20

[Command]
name = "hirari"
command =  D, B, a
time = 20

[Command]
name = "kibidango"
command = D, B, b

[Command]
name = "minidora"
command = D, B, c

[Command]
name = "turibori"
command = D, B, x

[Command]
name = "syabon"
command = D,B, y;~30$B, F, a
time = 10

[Command]
name = "shock"
command = D,B, z;~30$B, F, b
time = 10

[Command]
name = "mhand"
command = y+b
time = 10

[Command]
name = "SUTORO"
command = /D,c
time = 1
;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"       ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "FFF"       ;Required (do not remove)
command = F, F, F
time = 20

[Command]
name = "BB"       ;Required (do not remove)
command = B, B
time = 10

[Command]
name = "DORAMI"       ;Required (do not remove)
command = B, F, a
;time = 40

[Command]
name = "SUNE"       ;Required (do not remove)
command = B, F, b
;time = 30

[Command]
name = "JAI"       ;Required (do not remove)
command = B, F, c
;time = 20

[Command]
name = "SIZU"       ;Required (do not remove)
command = B, F, y
;time = 10

[Command]
name = "NOBI"       ;Required (do not remove)
command = B, F, x
;time = 1

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery" ;Required (do not remove)
command = a+b
time = 1

[Command]
name = "ab"
command = a+b
time = 1

[Command]
name = "abc"
command = a+b+c
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "fwd_b"
command = /F,b
time = 1

[Command]
name = "fwd_c"
command = /F,c
time = 1

[Command]
name = "downfwd_a"
command = /DF,a
time = 1

[Command]
name = "downfwd_b"
command = /DF,b
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "back_c"
command = /B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_ab"
command = /F, a+b
time = 1

[Command]
name = "back_ab"
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd"  ;Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback" ;Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup"   ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown" ;Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]
;===========================================================================
;KIKANSYA
[State -1]
type = ChangeState
value = 3400
triggerall = command = "KIKANSYA"
triggerall = power >= 10
triggerall = stateno != 3400
triggerall = stateno != 3500
triggerall = stateno != 3340
triggerall = stateno != 3350
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = hitdefattr = SC, NA
trigger2 = movecontact = 1
;===========================================================================
;URADORAMAN
[State -1]
type = ChangeState
value = 3500
triggerall = command = "URADORA"
triggerall = power >= 10
triggerall = stateno != 3400
triggerall = stateno != 3500
triggerall = stateno != 3340
triggerall = stateno != 3350
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = hitdefattr = SC, NA
trigger2 = movecontact = 1
;===========================================================================
;Superwaza A
[State -1]
type = ChangeState
value = 3000
triggerall = command = "YUUJYOUPOWER"
triggerall = power >= 10
triggerall = stateno != 3400
triggerall = stateno != 3500
triggerall = stateno != 3340
triggerall = stateno != 3350
triggerall = numprojID(1100) = 0
triggerall = numprojID(1110) = 0
triggerall = numprojID(1120) = 0
triggerall = numprojID(1130) = 0
triggerall = numprojID(1140) = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA
trigger2 = movecontact = 1
;===========================================================================
;NANKANAIKA
[State -1]
type = ChangeState
value = 3100
triggerall = command = "NANKANAIKA"
triggerall = power >= 10
triggerall = power < 20
triggerall = stateno != 3400
triggerall = stateno != 3500
triggerall = stateno != 3340
triggerall = stateno != 3350
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA
trigger2 = movecontact = 1
;===========================================================================
;NANKANAIKA2
[State -1]
type = ChangeState
value = 3110
triggerall = command = "NANKANAIKA"
triggerall = power >= 20
triggerall = power < 30
triggerall = stateno != 3400
triggerall = stateno != 3500
triggerall = stateno != 3340
triggerall = stateno != 3350
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA
trigger2 = movecontact = 1
;===========================================================================
;NANKANAIKA3
[State -1]
type = ChangeState
value = 3120
triggerall = command = "NANKANAIKA"
triggerall = power >= 30
triggerall = stateno != 34
triggerall = stateno != 3500
triggerall = stateno != 3340
triggerall = stateno != 3350
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA
trigger2 = movecontact = 1
;===========================================================================
;DORAYAKIN
[State -1]
type = ChangeState
value = 3200
triggerall = command = "DORAYAKIN"
triggerall = power >= 10
triggerall = power < 20
triggerall = numhelper(3200) = 0
triggerall = stateno != 3340
triggerall = stateno != 3350
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = statetype = A
trigger2 = hitdefattr = A,NA
trigger2 = movecontact = 1
;===========================================================================
;DORAYAKIN1.5
[State -1]
type = ChangeState
value = 3220
triggerall = command = "DORAYAKIN"
triggerall = power >= 20
triggerall = power < 30
triggerall = numhelper(3200) = 0
triggerall = stateno != 3340
triggerall = stateno != 3350
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = statetype = A
trigger2 = hitdefattr = A,NA
trigger2 = movecontact = 1
;===========================================================================
;DORAYAKIN2.0
[State -1]
type = ChangeState
value = 3240
triggerall = command = "DORAYAKIN"
triggerall = power >= 30
triggerall = numhelper(3200) = 0
triggerall = stateno != 3340
triggerall = stateno != 3350
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = statetype = A
trigger2 = hitdefattr = A,NA
trigger2 = movecontact = 1
;===========================================================================
;JYAI
[State -1]
type = ChangeState
value = 3301
triggerall = stateno != 3400
triggerall = command = "TOMODACHI"
triggerall = power >= 10
triggerall = stateno != 3400
triggerall = stateno != 3500
triggerall = stateno != 3340
triggerall = stateno != 3350
triggerall = numhelper(3300) = 0
triggerall = numhelper(3310) = 0
triggerall = numhelper(3320) = 0
triggerall = numhelper(3330) = 0
;triggerall = numhelper(3340) = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = hitdefattr = SC, NA
trigger2 = movecontact = 1
;---------------------------------------------------------------------------
;
[State -1]
type = ChangeState
value = 900 ;@@@@@@@@@@@@@XeCgiCNSj
triggerall = statetype = S ;@@ʏԂł鎖
triggerall = ctrl = 1 ;@@@@@@Rg[\ł鎖
triggerall = command = "fwd_a"
trigger1 = stateno != 100 ;@@@@ĂȂ
trigger1 = p2bodydist X < 4 ;@@Ƃ̋
trigger1 = p2statetype = S ;@@@肪Ă鎖
trigger1 = p2movetype != H ;@@肪U󂯂ĂȂiK[h܂ށj
;===========================================================================
;DORANEKO
[State -1]
type = ChangeState
value = 2700
triggerall = command = "doraneko"
trigger1 = statetype = S
trigger1 = ctrl = 1
;===========================================================================
;Hissatu C
[State -1]
type = ChangeState
value = 1700
triggerall = command = "syabon"
triggerall = numprojID(0) = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger2 = movecontact = 1
trigger3 = stateno = 400
trigger3 = movecontact = 1
trigger4 = stateno = 410
trigger4 = movecontact = 1
trigger5 = stateno = 200
trigger5 = movecontact = 1
;===========================================================================
;Hissatu D
[State -1]
type = ChangeState
value = 1800
triggerall = command = "shock"
triggerall = numprojID(0) = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger2 = movecontact = 1
trigger3 = stateno = 400
trigger3 = movecontact = 1
trigger4 = stateno = 410
trigger4 = movecontact = 1
trigger5 = stateno = 200
trigger5 = movecontact = 1
;===========================================================================
;Hissatu E
[State -1]
type = ChangeState
value = 1900
triggerall = command = "mhand"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger2 = movecontact = 1
trigger3 = stateno = 400
trigger3 = movecontact = 1
trigger4 = stateno = 410
trigger4 = movecontact = 1
;===========================================================================
;Hirari
[State -1]
type = ChangeState
value = 2000
triggerall = command = "hirari"
triggerall = numhelper(2000) = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
;===========================================================================
;door
[State -1]
type = ChangeState
value = 2100
triggerall = command = "door"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1

;===========================================================================
;neji
[State -1]
type = ChangeState
value = 2200
triggerall = command = "neji"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 2300
trigger4 = movecontact = 1
;===========================================================================
;kaminari
[State -1]
type = ChangeState
value = 2300
triggerall = command = "kaminari"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1

;===========================================================================
;korobasiya
[State -1]
type = ChangeState
value = 2400
triggerall = command = "korobasiya"
triggerall = numhelper(2400) = 0
triggerall = Life > 10
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1

;===========================================================================
;yari
[State -1]
type = ChangeState
value = 2500
triggerall = command = "yari"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 2300
trigger4 = movecontact = 1
;---------------------------------------------------------------------------
;AirDASH
[State -1]
type = ChangeState
value = 101
trigger1 = command = "FFF"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;HELP
[State -1]
type = ChangeState
value = 1140
triggerall = numprojID(1140) = 0
trigger1 = command = "DORAMI"
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;HELP
[State -1]
type = ChangeState
value = 1130
triggerall = numprojID(1130) = 0
trigger1 = command = "SUNE"
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;HELP
[State -1]
type = ChangeState
value = 1120
triggerall = numprojID(1120) = 0
trigger1 = command = "JAI"
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;HELP
[State -1]
type = ChangeState
value = 1110
triggerall = numprojID(1110) = 0
trigger1 = command = "SIZU"
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;HELP
[State -1]
type = ChangeState
value = 1100
triggerall = numprojID(1100) = 0
trigger1 = command = "NOBI"
trigger1 = statetype = S
trigger1 = ctrl = 1
;===========================================================================
;Hissatu A
[State -1]
type = ChangeState
value = 1500
triggerall = command = "kibidango"
triggerall = numhelper(1500) = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900
trigger2 = movecontact = 1
;===========================================================================
;Hissatu B
[State -1]
type = ChangeState
value = 1600
triggerall = command = "minidora"
triggerall = numhelper(1600) = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900
trigger2 = movecontact = 1
;===========================================================================
;turibori
[State -1]
type = ChangeState
value = 2600
triggerall = command = "turibori"
triggerall = numhelper(2600) = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 2300
trigger4 = movecontact = 1
;---------------------------------------------------------------------------
;Stand_A
[State -1]
type = ChangeState
value = 200
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = time > 7

;---------------------------------------------------------------------------
;Stand_B
[State -1]
type = ChangeState
value = 210
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Stand_C
[State -1]
type = ChangeState
value = 1020
triggerall = command = "c"
triggerall = numprojID(0) = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1

;---------------------------------------------------------------------------
;Crouch_A
[State -1]
type = ChangeState
value = 400
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
;---------------------------------------------------------------------------
;Crouch_B
[State -1]
type = ChangeState
value = 410
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400 ;crouch_a
trigger2 = movecontact = 1
trigger3 = stateno = 200 
trigger3 = movecontact = 1

;---------------------------------------------------------------------------
;Crouch_C
[State -1]
type = ChangeState
value = 420
triggerall = command = "c"
triggerall = command = "holddown"
triggerall = stateno != 420
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 410 ;crouch_b
trigger2 = movecontact = 1
trigger3 = stateno = 420
trigger3 = movecontact = 1
trigger4 = stateno = 200
trigger4 = movecontact = 1
trigger5 = stateno = 210
trigger5 = movecontact = 1
;===========================================================================
;SUTORO
[State -1]
type = ChangeState
value = 2800
triggerall = command = "SUTORO"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = movecontact = 1
trigger3 = stateno = 610
trigger3 = movecontact = 1
trigger4 = stateno = 620
trigger4 = movecontact = 1
trigger5 = stateno = 601
trigger5 = movecontact = 1
trigger6 = stateno = 611
trigger6 = movecontact = 1
;---------------------------------------------------------------------------
;Jump_A2
[State -1]
type = ChangeState
value = 601
triggerall = command = "NOBI"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = movecontact = 1
trigger3 = stateno = 610
trigger3 = movecontact = 1
trigger4 = stateno = 620
trigger4 = movecontact = 1
;---------------------------------------------------------------------------
;Jump_B2
[State -1]
type = ChangeState
value = 611
triggerall = command = "SIZU"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = movecontact = 1
trigger3 = stateno = 610
trigger3 = movecontact = 1
trigger4 = stateno = 620
trigger4 = movecontact = 1
trigger5 = stateno = 601
trigger5 = movecontact = 1
;---------------------------------------------------------------------------
;Jump_C2
[State -1]
type = ChangeState
value = 621
triggerall = numprojID(0) = 0
triggerall = command = "JAI"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = movecontact = 1
trigger3 = stateno = 610
trigger3 = movecontact = 1
trigger4 = stateno = 620
trigger4 = movecontact = 1
trigger5 = stateno = 611
trigger5 = movecontact = 1
;---------------------------------------------------------------------------
;Jump_A
[State -1]
type = ChangeState
value = 600
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = statetime >= 6

;---------------------------------------------------------------------------
;Jump_B
[State -1]
type = ChangeState
value = 610
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Jump_C
[State -1]
type = ChangeState
value = 620
triggerall = numproj = 0
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = movecontact = 1
trigger3 = stateno = 610
trigger3 = movecontact = 1
